.. Django Shop documentation master file, created by
   sphinx-quickstart on Mon Dec  6 14:42:25 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Shop's documentation!
=======================================

Contents:

.. toctree::
    :maxdepth: 3
    
    statement
    architecture
    requirements
    products
    taxes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

